@@ -18,6 +18,14 @@ $access{'upgrade'} = 0 if (&is_readonly_mode());	# too hard to fake
 &foreign_require("acl");
 %text = ( %webmin::text, %text );
 
+if (!defined($gconfig{'noselfwebminup'})) {
+	$access{'upgrade'} = 0
+		if (&webmin::has_repos());
+	}
+else {
+	$access{'upgrade'} = !$gconfig{'noselfwebminup'};
+	}
+
 $usermin_miniserv_config = "$config{'usermin_dir'}/miniserv.conf";
 $usermin_config = "$config{'usermin_dir'}/config";
 
@@ -463,7 +471,7 @@ if ($type eq 'rpm' && $file =~ /\.rpm$/i &&
 		return $text{'install_erpm'};
 		}
 	$redirect_to = $name = $2;
-	$out = &backquote_logged("rpm -U \"$file\" 2>&1");
+	$out = &backquote_logged("rpm -Uv \"$file\" 2>&1");
 	if ($?) {
 		unlink($file) if ($need_unlink);
 		return &text('install_eirpm', "<tt>$out</tt>");
@@ -864,22 +872,12 @@ sub flush_modules_cache
 
 =head2 stop_usermin
 
-Kills the running Usermin server process, returning undef on success or an
-error message on failure.
+Kills the running Usermin server process. Return value is always undef.
 
 =cut
 sub stop_usermin
 {
-local %miniserv;
-&get_usermin_miniserv_config(\%miniserv);
-local $pid;
-if (open(PID, "<".$miniserv{'pidfile'}) && ($pid = int(<PID>))) {
-	&kill_logged('TERM', $pid) || return &text('stop_ekill', $!);
-	close(PID);
-	}
-else {
-	return $text{'stop_efile'};
-	}
+&system_logged("$config{'usermin_dir'}/stop >/dev/null 2>&1 </dev/null");
 return undef;
 }
 
